@@ -1,11 +1,14 @@
 //! This module contains all the important structs and implementations to create, configure
 //! and run an application containing only a webview.
-use std::{env, net::SocketAddr, path::PathBuf};
+use std::{any::Any, env, net::SocketAddr, path::PathBuf, sync::{Arc, Mutex}};
 
 #[cfg(target_os = "linux")]
 use gtk::{Application, ApplicationWindow, Builder};
 #[cfg(target_os = "linux")]
 use webkit2gtk::WebView;
+#[cfg(target_os = "windows")]
+use core::marker::PhantomData;
+
 use tokio::runtime::Runtime;
 
 #[cfg(target_os = "linux")]
@@ -30,12 +33,10 @@ pub struct WarpSettings {
     /// # Example:
     ///
     /// ```
-    /// use std::net::SocketAddr;
-    /// 
     /// use serde::{Serialize, Deserialize};
     /// use tokio::runtime::Runtime;
     /// use warp::fs::dir;
-    /// use webview_app::{app::App, app::{AppSettings, WarpSettings}, warp_server::add_headers};
+    /// use webview_app::{app::App, app::{AppSettings, WarpInitData, WarpSettings}, warp_server::add_headers};
     /// use warp::{Filter, reply::{Json, json}};
     /// 
     /// #[derive(Serialize)]
@@ -56,7 +57,7 @@ pub struct WarpSettings {
     ///     //Err(warp::reject())
     /// }
     /// 
-    /// fn server(rt: &Runtime, socket_addr: SocketAddr, static_dir: String) {
+    /// fn server(rt: &Runtime, data: WarpInitData) {
     ///     rt.spawn(async move {
     /// 
     ///         let get_json = 
@@ -66,7 +67,7 @@ pub struct WarpSettings {
     ///             .and(warp::path::end())
     ///             .and_then(get_item);
     /// 
-    ///         let route_static = dir(static_dir)
+    ///         let route_static = dir(data.static_dir)
     ///             .map(add_headers);
     /// 
     ///         let routes = 
@@ -74,7 +75,7 @@ pub struct WarpSettings {
     ///             .or(route_static);
     /// 
     ///         warp::serve(routes)
-    ///             .run(socket_addr)
+    ///             .run(data.socket_addr)
     ///             .await;        
     ///     });
     /// }
@@ -99,7 +100,7 @@ pub struct WarpSettings {
     ///     run_app();
     /// }    
     /// ```
-    pub init_fn: Option<fn(rt: &Runtime, socket_addr: SocketAddr, static_dir: String)>,
+    pub init_fn: Option<fn(rt: &Runtime, data: WarpInitData)>,
 }
 
 impl Clone for WarpSettings {
@@ -152,12 +153,12 @@ pub struct AppSettings {
 
     // TODO: Windows
 
-    /// If you want to initialize your application or main window, set this callback. It is lso needed to inject a
+    /// If you want to initialize your application or main window, set this callback. It is also needed to inject a
     /// callback if you want to receive msgs from javascript.
     ///
     /// This option is only available on linux
     #[cfg(target_os = "linux")]
-    pub on_app_init: Option<fn(application: &Application, window: & ApplicationWindow, builder: &Option<Builder>, webview: & WebView)>,
+    pub on_app_init: Option<fn(data: InitData)>,
 
     //pub on_msg: Option<fn(application: &Application, window: &)
 
@@ -327,16 +328,50 @@ impl AppSettings {
     }
 }
 
+/// Data which is provided in the "on_app_init" method of "AppSettings"
+pub struct InitData<'a> {
+    /// The GTK Application. This is only available on Linux
+    #[cfg(target_os = "linux")]
+    pub application: &'a Application,
+    /// The GTK Application Window. This is only available on Linux
+    #[cfg(target_os = "linux")]
+    pub window: &'a ApplicationWindow,
+    /// The  GTK Builder, if chosen with flag "use_glade". This is only available on Linux
+    #[cfg(target_os = "linux")]
+    pub builder: &'a Option<Builder>,
+    /// The GTK WebView. This is only available on Linux
+    #[cfg(target_os = "linux")]
+    pub webview: &'a WebView,
+    /// Possibility to store arbitrary state. This is only available on Linux
+    #[cfg(target_os = "linux")]
+    pub state: Arc<Mutex<Box<dyn Any + Send>>>,
+    #[cfg(target_os = "windows")]
+    phantom: PhantomData<&'a i32>,
+}
+
+/// Data which is provided in the "init_fn" method of "WarpSettings"
+pub struct WarpInitData {
+    /// The socket address the warp server is using
+    pub socket_addr: SocketAddr, 
+    /// The static directory warp server is using for serving the web app
+    pub static_dir: String, 
+    /// Possibility to store arbitrary state. This is only available on Linux
+    pub state: Arc<Mutex<Box<dyn Any + Send>>>
+}
+
 /// This is the app running a window containig only a webview.
 pub struct App {
-    app: AppImpl
+    app: AppImpl,
+    state: Arc<Mutex<Box<dyn Any + Send>>>
 }
 
 impl App {
     /// Constructor to create and configure the app. 
     pub fn new(settings: AppSettings) -> Self {
+        let state: Arc<Mutex<Box<dyn Any + Send>>> = Arc::new(Mutex::new(Box::new(0)));
         App { 
-            app: AppImpl::new(settings) 
+            app: AppImpl::new(settings, state.clone()),
+            state
         }
     }
 
@@ -348,7 +383,7 @@ impl App {
             None
         };
         if let Some((ref rt, warp_settings)) = warp {
-            start(rt, warp_settings.clone())
+            start(rt, warp_settings.clone(), self.state.clone())
         }
 
         self.app.run();
