@@ -1,4 +1,4 @@
-use std::cell::RefCell;
+use std::{any::Any, cell::RefCell, sync::{Arc, Mutex}};
 
 use gtk::{Application, ApplicationWindow, Builder, prelude::{BuilderExtManual, GtkApplicationExt, GtkWindowExt, WidgetExt}};
 
@@ -12,7 +12,7 @@ pub struct MainWindow {
 }
 
 impl MainWindow {
-    pub fn new(application: &Application, settings: &AppSettings) -> Self {
+    pub fn new(application: &Application, settings: &AppSettings, state: Arc<Mutex<Box<dyn Any + Send>>>) -> Self {
         let window_pos_storage = match &settings.window_pos_storage_path {
             Some(store) => Some(WindowPosStorage::new(&store)),
             None => None
@@ -42,7 +42,7 @@ impl MainWindow {
         window.set_title(&settings.title);
         
         let webview = MainWebView::new(application, mainwindow.clone(), 
-            &builder, settings);
+            &builder, settings, state);
         webview.load(&settings.get_url());
         window.set_default_size(initial_size.0, initial_size.1);
 
